#
# spec file for package dolly
#
# Copyright (C) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
%define vers 0.63.1

Name:           dolly
Summary:        Tool for cloning the installation of one machine to other machines
License:        GPL-2.0-only
Group:          Productivity/Networking/Other
Version:        %vers
Release:        1.5
URL:            http://www.cs.inf.ethz.ch/stricker/CoPs/patagonia/dolly.html
Source0:        https://github.com/mslacken/dolly/archive/%{version}.tar.gz#/dolly-%{version}.tar.gz
Source1:        dolly.conf
Source2:        dolly.md

#SLE15* does not contain pandoc packages
%if 0%{?is_opensuse}
%ifnarch i586
BuildRequires:  pandoc
Requires:       gzip
%endif
%endif

%description
Dolly is used to clone the installation of one machine to
(possibly many) other machines. It can distribute image files
(even gnu-zipped), partitions or whole hard disk drives to
other partitions or hard disk drives. As it forms a "virtual TCP
ring" to distribute data, it works best with fast switched
networks (a 2 GB Windows NT partition clone
to 15 machines over Gigabit Ethernet was originally measured
to be less than 4 minutes).

As dolly clones whole partitions block-wise, it works for most
filesystems, including the types for Linux, Windows NT, Oberon,
Solaris.

%prep
%autosetup -p1
#mv %{name}-%{version}/* .
#rmdir %{name}-%{commit}/

%build
make %{?_smp_mflags}
%if 0%{?is_opensuse}
%ifnarch i586
pandoc --standalone -t man %{SOURCE2} -o dolly.1
gzip dolly.1
%endif
%endif

%install
install -D -m 755 $RPM_BUILD_DIR/%{name}-%{version}/dolly %{buildroot}%{_sbindir}/dolly
install -D -m 644  %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.conf
%if 0%{?is_opensuse}
%ifnarch i586
install -D -m 644 dolly.1.gz %{buildroot}%{_mandir}/man1/dolly.1.gz
%endif
%endif

%files
%doc README.md dolly.html dolly.example
%attr(755,root,root) %{_sbindir}/dolly
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/%{name}.conf
%if 0%{?is_opensuse}
%ifnarch i586
%{_mandir}/man1/dolly.1.gz
%endif
%endif

%changelog
* Tue Feb  9 2021 cgoll@suse.com
- updated to v0.63.1 which builds on i586
- disabled pandoc for i585
* Mon Feb  8 2021 jengelh@inai.de
- Remove obsolete specfile constructs. Depersonalize descriptions.
* Tue Feb  2 2021 cgoll@suse.com
- fixed the Makefile to support position independent code
* Fri Jan 29 2021 aginies@suse.com
- fix buildrequires for SLE (no pandoc package)
* Fri Jan 29 2021 cgoll@suse.com
- updated to version 0.63
- New features:
  * hosts can be resovled to ip addresses
  * works without dns resolution
* Fri Nov 20 2020 cgoll@suse.com
- added patch file: added-retries-for-connect.patch
* Wed Sep 11 2019 cgoll@suse.com
- updated to version 0.60
* Thu Jun  6 2019 cgoll@suse.com
- added man page and moved dolly to /usr/sbin/dolly
* Wed Apr 10 2019 aginies@suse.com
- 0.59 version
- fix typo in my name
* Mon Apr  8 2019 aginies@suse.com
- 0.58C version
